================================
Report a bug/Request a feature
================================

If you like to report a bug/request a feature/communicate any related problem
best way to reach us creating a new issue on our `GitHub repository <https://github.com/royerlab/aydin>`_.

You can also track pull-requests, milestones and our plans on our repository.
Feel free to participate in discussions and contribute but do not forget to
read our `contributing guidelines <https://github.com/royerlab/aydin/blob/master/CONTRIBUTING.md>`_ first.


